// *******************************************************
// *                                                     *
// *    JAVA  APPLIKATION:   SimpleTracking              *
// *                                                     *
// *    remote Kamera-Tracking mit einem                 *
// *    robot Objekt direkt vom Bildschirm               *
// *                                                     *
// *                                                     *
// *******************************************************
// *                                                     *
// *     CodeKit:    author  Jochen Viehoff              *
// *                                                     *
// *******************************************************


import java.awt.Frame;
import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;
import javax.swing.*;

public class SimpleTracking extends JFrame implements Runnable,MouseListener, MouseMotionListener {
    
    
    static int width =256;                    // display size
    static int height=256;
    static int dim = width*height;
    
    Thread animThread;                        // Thread for animation
    int delayAnim = 10;                       // Animation speed
    
    BufferedImage image   =null;
    Image         buffer = null;
    
    int [] pixel         = new int [dim];
    int [] pixelInit     = new int [dim];
    int [] temp          = new int [dim];
    
    int threshold = 150;
    
    static Rectangle screenCapture = new Rectangle(700,465,width,height);
    
    Robot           pixelRobot;                       // Robot object for screen capture
    
    //  ******************************************
    //     main method
    //  ******************************************
    
    public static void main(String[] args) {
        
        SimpleTracking myTracking = new SimpleTracking();
        myTracking.setSize(width,height);
        myTracking.setBackground(Color.white);
        myTracking.show();
    }
    
    //  ******************************************
    //       overwrite paint method
    //  ******************************************
    
    public void paint(Graphics g) {
        
        for (int i=0;i<dim;i++){
            
            if (Math.abs((temp[i] & 0xff) - (pixelInit[i] & 0xff)) < threshold)  // Kanal: blau
                
                pixel[i] = 0xFF000000;   // schwarz
            else
                pixel[i] = 0xFFFFFFFF;   //  weiss
        }
        
        buffer =  createImage(new MemoryImageSource(width,height,pixel,0,width));
        g.drawImage(buffer,0,0,null);
    }
    
    //  ******************************************
    //       overwrite update method
    //  ******************************************
    
    public void update(Graphics g) {
        paint(g);
    }
    
    //  ******************************************
    //       constructor
    //  ******************************************
    
    public SimpleTracking() {
        
        // start pixel robot
        try { pixelRobot = new Robot(); }
        catch(AWTException awte) {System.out.println(awte);}
        
        // Start: MouseListener
        addMouseListener(this);
        addMouseMotionListener(this);
        
        // start animation thread
        animThread = new Thread(this);
        animThread.start();
    }
    
    //  ******************************************
    //       animation thread: run methode
    //  ******************************************
    
    public void run() {
        
        while (animThread != null ) {
            
            try {Thread.sleep(delayAnim);}              // sleep a while
            catch (InterruptedException e) {}
            
            image=pixelRobot.createScreenCapture(screenCapture);      // grab pixels from screen
            temp = image.getRGB(0,0,width,height,temp,0,width);
            
            repaint();                                                // draw new image
        }
    }
    
    // ****************************************************
    //   Mouse Events
    // ****************************************************
    
    public void mousePressed(MouseEvent e)   {}
    public void mouseReleased(MouseEvent e)  {}
    
    public void mouseClicked(MouseEvent e)  {
        
        image=pixelRobot.createScreenCapture(screenCapture);      // grab pixels from screen
        pixelInit = image.getRGB(0,0,width,height,pixelInit,0,width);
    }
    
    public void mouseEntered(MouseEvent e)  {}
    public void mouseExited(MouseEvent e)   {}
    public void mouseDragged(MouseEvent e)  {}
    public void mouseMoved(MouseEvent e)    {}
}
// ******************************************************
// ******************************************************


